#[repr(C)]
pub struct cipher_base_t {
pub cipher: cipher_id_t,
pub ecb_func: Option<unsafe extern "C" fn(ctx: *mut c_void, mode: operation_t, input: *const c_uchar, output: *mut c_uchar) -> c_int>,
pub cbc_func: Option<unsafe extern "C" fn(ctx: *mut c_void, mode: operation_t, length: size_t, iv: *mut c_uchar, input: *const c_uchar, output: *mut c_uchar) -> c_int>,
pub cfb_func: Option<unsafe extern "C" fn(ctx: *mut c_void, mode: operation_t, length: size_t, iv_off: *mut size_t, iv: *mut c_uchar, input: *const c_uchar, output: *mut c_uchar) -> c_int>,
pub ofb_func: Option<unsafe extern "C" fn(ctx: *mut c_void, length: size_t, iv_off: *mut size_t, iv: *mut c_uchar, input: *const c_uchar, output: *mut c_uchar) -> c_int>,
pub ctr_func: Option<unsafe extern "C" fn(ctx: *mut c_void, length: size_t, nc_off: *mut size_t, nonce_counter: *mut c_uchar, stream_block: *mut c_uchar, input: *const c_uchar, output: *mut c_uchar) -> c_int>,
pub xts_func: Option<unsafe extern "C" fn(ctx: *mut c_void, mode: operation_t, length: size_t, data_unit: *const c_uchar, input: *const c_uchar, output: *mut c_uchar) -> c_int>,
pub stream_func: Option<unsafe extern "C" fn(ctx: *mut c_void, length: size_t, input: *const c_uchar, output: *mut c_uchar) -> c_int>,
pub setkey_enc_func: Option<unsafe extern "C" fn(ctx: *mut c_void, key: *const c_uchar, key_bitlen: c_uint) -> c_int>,
pub setkey_dec_func: Option<unsafe extern "C" fn(ctx: *mut c_void, key: *const c_uchar, key_bitlen: c_uint) -> c_int>,
pub ctx_alloc_func: Option<unsafe extern "C" fn() -> *mut c_void>,
pub ctx_free_func: Option<unsafe extern "C" fn(ctx: *mut c_void)>,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.