#[repr(C)]
pub struct cipher_context_t {
pub cipher_info: *const cipher_info_t,
pub key_bitlen: c_int,
pub operation: operation_t,
pub add_padding: Option<unsafe extern "C" fn(output: *mut c_uchar, olen: size_t, data_len: size_t)>,
pub get_padding: Option<unsafe extern "C" fn(input: *mut c_uchar, ilen: size_t, data_len: *mut size_t) -> c_int>,
pub unprocessed_data: [c_uchar; 16],
pub unprocessed_len: size_t,
pub iv: [c_uchar; 16],
pub iv_size: size_t,
pub cipher_ctx: *mut c_void,
pub cmac_ctx: *mut cmac_context_t,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.