#[repr(C)]
pub struct ctr_drbg_context {
pub counter: [c_uchar; 16],
pub reseed_counter: c_int,
pub prediction_resistance: c_int,
pub entropy_len: size_t,
pub reseed_interval: c_int,
pub aes_ctx: aes_context,
pub f_entropy: Option<unsafe extern "C" fn(arg1: *mut c_void, arg2: *mut c_uchar, arg3: size_t) -> c_int>,
pub p_entropy: *mut c_void,
pub mutex: threading_mutex_t,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.