#[repr(C)]
pub struct ecjpake_context {
pub md_info: *const md_info_t,
pub grp: ecp_group,
pub role: ecjpake_role,
pub point_format: c_int,
pub Xm1: ecp_point,
pub Xm2: ecp_point,
pub Xp1: ecp_point,
pub Xp2: ecp_point,
pub Xp: ecp_point,
pub xm1: mpi,
pub xm2: mpi,
pub s: mpi,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.