#[repr(C)]
pub struct x509write_cert {
pub version: c_int,
pub serial: mpi,
pub subject_key: *mut pk_context,
pub issuer_key: *mut pk_context,
pub subject: *mut asn1_named_data,
pub issuer: *mut asn1_named_data,
pub md_alg: md_type_t,
pub not_before: [c_char; 16],
pub not_after: [c_char; 16],
pub extensions: *mut asn1_named_data,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.